==> estateplat-common-1.2.3-20180102.074335-1-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzyTt.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源滩涂表
 */
@Table(name = "zrzy_tt")
public class ZrzyTt extends ZrzyParent implements ZrzyVo, InsertVo {
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源ID
     */
    @Id
    private String zrzyid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源编号
     */
    private String zrzybh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 名称
     */
    private String mc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元号
     */
    private String zrzydyh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 分布
     */
    private String fb;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积
     */
    private Double mj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 围垦情况
     */
    private String wkqk;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 水位
     */
    private Double sw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 岸线
     */
    private String ax;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 高程
     */
    private Double gc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 水下地形
     */
    private String sxdx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 潮间带
     */
    private String cjd;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查人
     */
    private String dcr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查时间
     */
    private Date dcsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权属状态
     */
    private String qszt;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质量
     */
    private String zhl;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 数量
     */

    private Double sl;

    public String getZrzyid() {
        return zrzyid;
    }

    public void setZrzyid(String zrzyid) {
        this.zrzyid = zrzyid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZrzybh() {
        return zrzybh;
    }

    public void setZrzybh(String zrzybh) {
        this.zrzybh = zrzybh;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getZrzydyh() {
        return zrzydyh;
    }

    public void setZrzydyh(String zrzydyh) {
        this.zrzydyh = zrzydyh;
    }

    public String getFb() {
        return fb;
    }

    public void setFb(String fb) {
        this.fb = fb;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getWkqk() {
        return wkqk;
    }

    public void setWkqk(String wkqk) {
        this.wkqk = wkqk;
    }

    public Double getSw() {
        return sw;
    }

    public void setSw(Double sw) {
        this.sw = sw;
    }

    public String getAx() {
        return ax;
    }

    public void setAx(String ax) {
        this.ax = ax;
    }

    public Double getGc() {
        return gc;
    }

    public void setGc(Double gc) {
        this.gc = gc;
    }

    public String getSxdx() {
        return sxdx;
    }

    public void setSxdx(String sxdx) {
        this.sxdx = sxdx;
    }

    public String getCjd() {
        return cjd;
    }

    public void setCjd(String cjd) {
        this.cjd = cjd;
    }

    public String getDcr() {
        return dcr;
    }

    public void setDcr(String dcr) {
        this.dcr = dcr;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getZhl() {
        return zhl;
    }

    public void setZhl(String zhl) {
        this.zhl = zhl;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }
}

==> estateplat-common-1.2.3-20180523.065010-94-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzyTt.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源滩涂表
 */
@Table(name = "zrzy_tt")
public class ZrzyTt extends ZrzyParent implements ZrzyVo, InsertVo {
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源ID
     */
    @Id
    private String zrzyid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源编号
     */
    private String zrzybh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 名称
     */
    private String mc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元号
     */
    private String zrzydyh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 分布
     */
    private String fb;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积
     */
    private Double mj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 围垦情况
     */
    private String wkqk;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 水位
     */
    private Double sw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 岸线
     */
    private String ax;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 高程
     */
    private Double gc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 水下地形
     */
    private String sxdx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 潮间带
     */
    private String cjd;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查人
     */
    private String dcr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 调查时间
     */
    private Date dcsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权属状态
     */
    private String qszt;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质量
     */
    private String zhl;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 数量
     */

    private Double sl;

    /**
     * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
     * @description 类别
     */
    private String lb;

    public String getZrzyid() {
        return zrzyid;
    }

    public void setZrzyid(String zrzyid) {
        this.zrzyid = zrzyid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZrzybh() {
        return zrzybh;
    }

    public void setZrzybh(String zrzybh) {
        this.zrzybh = zrzybh;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getZrzydyh() {
        return zrzydyh;
    }

    public void setZrzydyh(String zrzydyh) {
        this.zrzydyh = zrzydyh;
    }

    public String getFb() {
        return fb;
    }

    public void setFb(String fb) {
        this.fb = fb;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getWkqk() {
        return wkqk;
    }

    public void setWkqk(String wkqk) {
        this.wkqk = wkqk;
    }

    public Double getSw() {
        return sw;
    }

    public void setSw(Double sw) {
        this.sw = sw;
    }

    public String getAx() {
        return ax;
    }

    public void setAx(String ax) {
        this.ax = ax;
    }

    public Double getGc() {
        return gc;
    }

    public void setGc(Double gc) {
        this.gc = gc;
    }

    public String getSxdx() {
        return sxdx;
    }

    public void setSxdx(String sxdx) {
        this.sxdx = sxdx;
    }

    public String getCjd() {
        return cjd;
    }

    public void setCjd(String cjd) {
        this.cjd = cjd;
    }

    public String getDcr() {
        return dcr;
    }

    public void setDcr(String dcr) {
        this.dcr = dcr;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getZhl() {
        return zhl;
    }

    public void setZhl(String zhl) {
        this.zhl = zhl;
    }

    public Double getSl() {
        return sl;
    }

    public void setSl(Double sl) {
        this.sl = sl;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }
}
